# coding: utf-8
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jmb.i18n.models import Language


class Category(StatusModel, DateModel, UserModel, OrderedModel):
    name = models.CharField(
        max_length=100,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=100,
        unique=True,
        verbose_name=_('slug'),
    )

    def __unicode__(self):
        return self.name


class Question(StatusModel, DateModel, UserModel, OrderedModel):
    category = models.ForeignKey(
        Category,
        verbose_name=_('category'),
    )
    qtype = models.CharField(
        max_length=2,
        choices=settings.SURVEY_QUESTION_QTYPE_CHOICES,
        verbose_name=_('question type'),
    )
    required = models.BooleanField(
        default=True,
        verbose_name=_('required'),
    )
    language = models.ForeignKey(
        Language,
        verbose_name=_('language'),
    )
    question = models.TextField(
        unique=True,
        verbose_name=_('question text'),
    )
    choice_num_min = models.IntegerField(
        null=True, blank=True,
        verbose_name=_("minimum number of choices"),
    )
    choice_num_max = models.IntegerField(
        null=True, blank=True,
        verbose_name=_("maximum number of choices"),
    )
    default = models.BooleanField(
        verbose_name=_("default"),
        default=True,
    )

    def get_choices(self):
        choices = self.choices.all().values('choice')
        list_choices = []
        for choice in choices:
            list_choices.append(choice['choice'])
        return ', '.join(list_choices)
    get_choices.short_description = _('choices')

    def get_link_required(self):
        return """
            <a id='jmb_question_required_%s' href='#'>
                <img alt="False" src="/static/admin/img/icon-%s.gif">
            </a>""" % (self.id, ('yes' if self.required else 'no'))
    get_link_required.short_description = _('Required')
    get_link_required.allow_tags = True

    def __unicode__(self):
        return self.question

    class Meta:
        verbose_name = _("question")
        verbose_name_plural = _("questions")
        ordering = ('ordering', 'question')


class Choice(DateModel, UserModel, OrderedModel):
    question = models.ForeignKey(
        Question,
        related_name='choices',
        verbose_name=_('question'),
    )
    choice = models.CharField(
        max_length=500,
        verbose_name=_('choice text'),
    )

    def __unicode__(self):
        return self.choice

    class Meta:
        verbose_name = _("Choice")
        verbose_name_plural = _("Choices")
        unique_together = (('question', 'choice'),)
        order_with_respect_to = 'question'
        ordering = ('question', 'ordering')


class Answer(DateModel, UserModel):
    """
    Answer base class.
    Must be inherited to set associated contact/user.
    """
    question = models.ForeignKey(
        Question,
        verbose_name=_('question'),
        editable=False,
    )
    answer = models.TextField(
        verbose_name=_('answer text')
    )
    submission_date = models.DateTimeField(
        auto_now=True,
        verbose_name=_("submission date"),
    )

    class Meta:
        abstract = True


#if settings.CMS_ENABLED:
#     import jmb.survey.cms.plugins
#     import namespace.appname.model.cms.app
